@@ -55,6 +55,7 @@ wording = {
     'metacritic':'Reviews on metacritic.com',
     'imdb':'Movies on IMDb.com',
     'wikipedia':'Wikipedia',
+    'wiktionary':'Wiktionary',
     'amazon':'Amazon',
     'maemo':'Maemo.org',
     }
@@ -64,8 +65,9 @@ reg_maemo = re.compile(r'( - maemo\.org wiki|maemo\.org - package overview for |
 
 about_txt = """
 Ask Ziggy - Search for news, weather, translations, reviews,\t\t
- movies, wikipedia entries and more...\n
+ movies, wikipedia or wiktionary entries and more...\n
 <small>&#169; 2010 Martin Borho &lt;martin@borho.net&gt;\t\t\t\n
+Thanks to maemo.org and to Laurent Gautrot for adding wiktionary!\t\t\n
 License: GNU General Public License (GPL) Version 3
 Source: <span color="orange">http://github.com/mborho/ask-ziggy</span></small>
 """
@@ -303,6 +305,13 @@ class BaasGui(object):
         qbutton.connect("toggled", self.menu_settings_toggled, 'hide_quick')
         qbutton.set_active(self.state.hide_quick)
         
+        # service check button
+        mbutton = CheckButton(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT)
+        mbutton.set_label('use google mobilizer to open webpages')
+        mbutton.set_size_request(750, 70)
+        mbutton.set_active(self.state.mobilizer)
+        mbutton.connect("toggled", self.menu_settings_toggled, 'mobilizer')        
+        
         # service check button
         lbutton = CheckButton(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT)
         lbutton.set_label('open urls directly in browser')
@@ -316,23 +325,16 @@ class BaasGui(object):
         pbutton.set_size_request(750, 70)
         pbutton.set_active(self.state.use_proxy)
         pbutton.connect("toggled", self.menu_settings_toggled, 'use_proxy')
-
-        # service check button
-        mbutton = CheckButton(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT)
-        mbutton.set_label('use google mobilizer to open webpages')
-        mbutton.set_size_request(750, 70)
-        mbutton.set_active(self.state.mobilizer)
-        mbutton.connect("toggled", self.menu_settings_toggled, 'mobilizer')
         
         # history len
         len_box = self.menu_select_history_len()
 
         box2 = VBox(False)
-        box2.pack_start(len_box, False, False, 2)
+        box2.pack_start(len_box, False, False, 2)        
         box2.pack_start(qbutton, True, True, 2)
-        box2.pack_start(lbutton, True, True, 2)
-        box2.pack_start(pbutton, True, True, 2)
         box2.pack_start(mbutton, True, True, 2)
+        box2.pack_start(lbutton, True, True, 2)
+        box2.pack_start(pbutton, True, True, 2)        
 
         parea = PannableArea()
         parea.add_with_viewport(box2)
@@ -1344,4 +1346,4 @@ class BaasGui(object):
             proxy = "http://%s:%s/"% (http,port)
             import os
             os.environ['http_proxy'] = proxy
-            print "setting proxy to", proxy
\ No newline at end of file
+            print "setting proxy to", proxy
